import logging
import re
from typing import Iterable, List, Optional, TypeVar, Union

from grpc import Channel

from .crypto import PrivateKey
from .pb.DeployServiceCommon_pb2 import (
    BlockInfo, BlockQuery, BlocksQuery, DataAtNameQuery, LightBlockInfo,
)
from .pb.DeployServiceV1_pb2 import (
    BlockInfoResponse, BlockResponse, DeployResponse,
    ListeningNameDataPayload as Data, ListeningNameDataResponse,
    VisualizeBlocksResponse,
)
from .pb.DeployServiceV1_pb2_grpc import DeployServiceStub
from .pb.ProposeServiceCommon_pb2 import PrintUnmatchedSendsQuery
from .pb.ProposeServiceV1_pb2 import ProposeResponse
from .pb.ProposeServiceV1_pb2_grpc import ProposeServiceStub
from .pb.RhoTypes_pb2 import Expr, GDeployId, GUnforgeable, Par
from .util import create_deploy_data

GRPC_Response_T = Union[ProposeResponse,
                        DeployResponse,
                        ListeningNameDataResponse,
                        BlockResponse,
                        BlockInfoResponse,
                        VisualizeBlocksResponse]

GRPC_StreamResponse_T = Union[BlockInfoResponse, VisualizeBlocksResponse]
T = TypeVar("T")

propose_result_match = re.compile(r'Success! Block (?P<block_hash>[0-9a-f]+) created and added.')

class RClientException(Exception):

    def _init__(self, message: str):
        super().__init__(message)


class DataQueries:

    @staticmethod
    def public_names(names: List[str]) -> Par:
        exprs = [Expr(g_string=n) for n in names]
        return Par(exprs=exprs)

    @staticmethod
    def deploy_id(deploy_id: str) -> Par:
        g_deploy_id = GDeployId(sig=bytes.fromhex(deploy_id))
        g_unforgeable = GUnforgeable(g_deploy_id_body=g_deploy_id)
        return Par(unforgeables=[g_unforgeable])


class RClient:

    def __init__(self, channel: Channel):
        self.channel = channel

    def _check_response(self, response: GRPC_Response_T):
        logging.debug('gRPC response: %s', str(response))
        if response.WhichOneof("message") == 'error':
            raise RClientException('\n'.join(response.error.messages))

    def _handle_stream(self, response: Iterable[GRPC_StreamResponse_T]) -> List[GRPC_StreamResponse_T]:
        result = []
        for resp in response:
            self._check_response(resp)
            result.append(resp)
        return result

    def deploy_with_vabn_filled(
            self,
            key: PrivateKey,
            term: str,
            phlo_price: int,
            phlo_limit: int,
            timestamp_millis: int = -1
        ) -> str:
        latest_blocks = self.show_blocks(1)
        # when the genesis block is not ready, it would be empty in show_blocks
        # it could return more than 1 block when there are multiple blocks at the same height
        assert len(latest_blocks) >= 1, "No latest block found"
        latest_block = latest_blocks[0]
        latest_block_num = latest_block.blockNumber
        return self.deploy(key, term, phlo_price, phlo_limit, latest_block_num, timestamp_millis)

    def deploy(
            self,
            key: PrivateKey,
            term: str,
            phlo_price: int,
            phlo_limit: int,
            valid_after_block_no: int = -1,
            timestamp_millis: int = -1
        ) -> str:
        deploy_data = create_deploy_data(
            key, term, phlo_price, phlo_limit, valid_after_block_no, timestamp_millis
        )
        stub = DeployServiceStub(self.channel)
        response = stub.doDeploy(deploy_data)
        self._check_response(response)
        # sig of deploy data is deployId
        return deploy_data.sig.hex()

    def show_block(self, block_hash: str) -> BlockInfo:
        block_query = BlockQuery(hash=block_hash)
        stub = DeployServiceStub(self.channel)
        response = stub.getBlock(block_query)
        self._check_response(response)
        return response.blockInfo

    def show_blocks(self, depth: int = 1) -> List[LightBlockInfo]:
        blocks_query = BlocksQuery(depth=depth)
        stub = DeployServiceStub(self.channel)
        response = stub.getBlocks(blocks_query)
        result = self._handle_stream(response)
        return list(map(lambda x:x.blockInfo, result))  # type: ignore

    def propose(self) -> str:
        stub = ProposeServiceStub(self.channel)
        response: ProposeResponse = stub.propose(PrintUnmatchedSendsQuery(printUnmatchedSends=False))
        self._check_response(response)
        match_result = propose_result_match.match(response.result)
        assert match_result is not None
        return match_result.group("block_hash")

    def get_data_at_name(self, par: Par, depth: int = -1) -> Data:
        query = DataAtNameQuery(depth=depth, name=par)
        stub = DeployServiceStub(self.channel)
        response = stub.listenForDataAtName(query)
        self._check_response(response)
        wrapped = response.payload
        return Data.FromString(wrapped.SerializeToString())

    def get_data_at_public_names(self, names: List[str], depth: int = -1) -> Optional[Data]:
        return self.get_data_at_name(DataQueries.public_names(names), depth)

    def get_data_at_deploy_id(self, deploy_id: str, depth: int = -1) -> Optional[Data]:
        return self.get_data_at_name(DataQueries.deploy_id(deploy_id), depth)



import pytest
from cryptography import x509
from cryptography.hazmat.backends import default_backend
from cryptography.hazmat.primitives import hashes
from cryptography.hazmat.primitives.serialization import load_pem_private_key
from cryptography.x509.oid import NameOID
from rchain.certificate import (
    generate_node_tls_key_cert_id, get_node_id_raw, get_node_tls_cert_pem,
    get_node_tls_cn, get_node_tls_key_pem,
)

certs_examples = [
        (
            b"""-----BEGIN PRIVATE KEY-----
MEECAQAwEwYHKoZIzj0CAQYIKoZIzj0DAQcEJzAlAgEBBCDgWIf2/YwI9Hfql9uz
vI7Q9rxtqFgD/v+xc6oCZHrG8A==
-----END PRIVATE KEY-----
""",
            b'\xf7\x08\x8duZ\xc1n\xa6\x11\xa4B\x89\x1a\xc0\x16\x0e\xde\t\x00\xa5',
            "f7088d755ac16ea611a442891ac0160ede0900a5",
        ),
        (
            b"""-----BEGIN PRIVATE KEY-----
MEECAQAwEwYHKoZIzj0CAQYIKoZIzj0DAQcEJzAlAgEBBCC9vPBp5CSZw2zs9lWn
MdjHRMlYWpo+ZYTWnnE0P2Mysg==
-----END PRIVATE KEY-----
""",
            b'\x900\xf1G/w\x91\x9bw@\xae\xa5\xb2\x05\xe3\x85qwK\x1d',
            "9030f1472f77919b7740aea5b205e38571774b1d",
        ),
        (
            b"""-----BEGIN PRIVATE KEY-----
MEECAQAwEwYHKoZIzj0CAQYIKoZIzj0DAQcEJzAlAgEBBCB47F2X0/9s3M5N5rKW
cHuiNCGoQZXxz82LhOLhUQaFmg==
-----END PRIVATE KEY-----
""",
            b'PJ\xdb\x8f\xdbj \xf5\xf0\x83\xdf\xd7a\x90\x16\x97Y\xd0\x0eu',
            "504adb8fdb6a20f5f083dfd76190169759d00e75",
        )
    ]

def check_cert(actual_cert: x509.Certificate, expected_tls_cn: str):
    assert isinstance(actual_cert.signature_hash_algorithm, hashes.SHA256)
    assert actual_cert.signature_algorithm_oid.dotted_string == '1.2.840.10045.4.3.2'  # ecdsa-with-sha256
    actual_issuer_cn = actual_cert.issuer.get_attributes_for_oid(NameOID.COMMON_NAME)[0].value
    assert actual_issuer_cn == expected_tls_cn
    actual_subject_cn = actual_cert.subject.get_attributes_for_oid(NameOID.COMMON_NAME)[0].value
    assert actual_subject_cn == expected_tls_cn


@pytest.mark.parametrize("private_key_pem,tls_cn_name,expected_tls_cn", certs_examples)
def test_get_node_tls_key_pem(private_key_pem: bytes, tls_cn_name: str, expected_tls_cn: str):
    private_key = load_pem_private_key(private_key_pem, None, default_backend())
    assert private_key_pem.decode('utf8') ==  get_node_tls_key_pem(private_key)

@pytest.mark.parametrize("private_key_pem,tls_cn_name,expected_tls_cn", certs_examples)
def test_get_node_tls_cn(private_key_pem: bytes, tls_cn_name: str, expected_tls_cn: str):
    private_key = load_pem_private_key(private_key_pem, None, default_backend())
    actual_node_id_raw = get_node_id_raw(private_key)
    actual_tls_cn = get_node_tls_cn(actual_node_id_raw)
    assert actual_node_id_raw == tls_cn_name
    assert actual_tls_cn == expected_tls_cn

@pytest.mark.parametrize("private_key_pem,tls_cn_name,expected_tls_cn", certs_examples)
def test_get_node_tls_cert_pem(private_key_pem: bytes, tls_cn_name: str, expected_tls_cn: str):
    private_key = load_pem_private_key(private_key_pem, None, default_backend())
    cert_pem = get_node_tls_cert_pem(private_key)
    actual_cert = x509.load_pem_x509_certificate(cert_pem.encode('utf8'), default_backend())
    check_cert(actual_cert, expected_tls_cn)


def test_generate_node_tls_key_cert_id():
    key_pem, cert_pem, node_id = generate_node_tls_key_cert_id()
    private_key = load_pem_private_key(key_pem.encode('utf8'), None, default_backend())
    cert = x509.load_pem_x509_certificate(cert_pem.encode('utf8'), default_backend())
    expected_tls_cn = get_node_tls_cn(get_node_id_raw(private_key))
    check_cert(cert, expected_tls_cn)




# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: DeployServiceCommon.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import CasperMessage_pb2 as CasperMessage__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from .scalapb import scalapb_pb2 as scalapb_dot_scalapb__pb2
from . import RhoTypes_pb2 as RhoTypes__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='DeployServiceCommon.proto',
  package='casper',
  syntax='proto3',
  serialized_options=_b('\342?!\n\033coop.rchain.casper.protocol\020\001(\001'),
  serialized_pb=_b('\n\x19\x44\x65ployServiceCommon.proto\x12\x06\x63\x61sper\x1a\x13\x43\x61sperMessage.proto\x1a\x1bgoogle/protobuf/empty.proto\x1a\x15scalapb/scalapb.proto\x1a\x0eRhoTypes.proto\"#\n\x0f\x46indDeployQuery\x12\x10\n\x08\x64\x65ployId\x18\x01 \x01(\x0c\"\x1a\n\nBlockQuery\x12\x0c\n\x04hash\x18\x01 \x01(\t\"\x1c\n\x0b\x42locksQuery\x12\r\n\x05\x64\x65pth\x18\x01 \x01(\x05\"4\n\x0f\x44\x61taAtNameQuery\x12\r\n\x05\x64\x65pth\x18\x01 \x01(\x05\x12\x12\n\x04name\x18\x02 \x01(\x0b\x32\x04.Par\"=\n\x17\x43ontinuationAtNameQuery\x12\r\n\x05\x64\x65pth\x18\x01 \x01(\x05\x12\x13\n\x05names\x18\x02 \x03(\x0b\x32\x04.Par\"B\n\x11VisualizeDagQuery\x12\r\n\x05\x64\x65pth\x18\x01 \x01(\x05\x12\x1e\n\x16showJustificationLines\x18\x02 \x01(\x08\"\x14\n\x12MachineVerifyQuery\"K\n\x17PrivateNamePreviewQuery\x12\x0c\n\x04user\x18\x01 \x01(\x0c\x12\x11\n\ttimestamp\x18\x02 \x01(\x03\x12\x0f\n\x07nameQty\x18\x03 \x01(\x05\"\x19\n\x17LastFinalizedBlockQuery\" \n\x10IsFinalizedQuery\x12\x0c\n\x04hash\x18\x01 \x01(\t\"$\n\x0f\x42ondStatusQuery\x12\x11\n\tpublicKey\x18\x01 \x01(\x0c\",\n\x08\x42ondInfo\x12\x11\n\tvalidator\x18\x01 \x01(\t\x12\r\n\x05stake\x18\x02 \x01(\x03\"\xe1\x01\n\nDeployInfo\x12\x10\n\x08\x64\x65ployer\x18\x01 \x01(\t\x12\x0c\n\x04term\x18\x02 \x01(\t\x12\x11\n\ttimestamp\x18\x03 \x01(\x03\x12\x0b\n\x03sig\x18\x04 \x01(\t\x12\x14\n\x0csigAlgorithm\x18\x05 \x01(\t\x12\x11\n\tphloPrice\x18\x07 \x01(\x03\x12\x11\n\tphloLimit\x18\x08 \x01(\x03\x12\x1d\n\x15validAfterBlockNumber\x18\t \x01(\x03\x12\x0c\n\x04\x63ost\x18\n \x01(\x04\x12\x0f\n\x07\x65rrored\x18\x0b \x01(\x08\x12\x19\n\x11systemDeployError\x18\x0c \x01(\t\"\x9d\x03\n\x0eLightBlockInfo\x12\x11\n\tblockHash\x18\x01 \x01(\t\x12\x0e\n\x06sender\x18\x02 \x01(\t\x12\x0e\n\x06seqNum\x18\x03 \x01(\x03\x12\x0b\n\x03sig\x18\x04 \x01(\t\x12\x14\n\x0csigAlgorithm\x18\x05 \x01(\t\x12\x0f\n\x07shardId\x18\x06 \x01(\t\x12\x12\n\nextraBytes\x18\x07 \x01(\x0c\x12\x0f\n\x07version\x18\x08 \x01(\x03\x12\x11\n\ttimestamp\x18\t \x01(\x03\x12\x18\n\x10headerExtraBytes\x18\n \x01(\x0c\x12\x17\n\x0fparentsHashList\x18\x0b \x03(\t\x12\x13\n\x0b\x62lockNumber\x18\x0c \x01(\x03\x12\x14\n\x0cpreStateHash\x18\r \x01(\t\x12\x15\n\rpostStateHash\x18\x0e \x01(\t\x12\x16\n\x0e\x62odyExtraBytes\x18\x0f \x01(\x0c\x12\x1f\n\x05\x62onds\x18\x10 \x03(\x0b\x32\x10.casper.BondInfo\x12\x11\n\tblockSize\x18\x11 \x01(\t\x12\x13\n\x0b\x64\x65ployCount\x18\x12 \x01(\x05\x12\x16\n\x0e\x66\x61ultTolerance\x18\x13 \x01(\x02\"[\n\tBlockInfo\x12)\n\tblockInfo\x18\x01 \x01(\x0b\x32\x16.casper.LightBlockInfo\x12#\n\x07\x64\x65ploys\x18\x02 \x03(\x0b\x32\x12.casper.DeployInfo\"W\n\x11\x44\x61taWithBlockInfo\x12\x1b\n\rpostBlockData\x18\x01 \x03(\x0b\x32\x04.Par\x12%\n\x05\x62lock\x18\x02 \x01(\x0b\x32\x16.casper.LightBlockInfo\"\x84\x01\n\x1a\x43ontinuationsWithBlockInfo\x12?\n\x16postBlockContinuations\x18\x01 \x03(\x0b\x32\x1f.casper.WaitingContinuationInfo\x12%\n\x05\x62lock\x18\x02 \x01(\x0b\x32\x16.casper.LightBlockInfo\"g\n\x17WaitingContinuationInfo\x12\'\n\x11postBlockPatterns\x18\x01 \x03(\x0b\x32\x0c.BindPattern\x12#\n\x15postBlockContinuation\x18\x02 \x01(\x0b\x32\x04.ParB$\xe2?!\n\x1b\x63oop.rchain.casper.protocol\x10\x01(\x01\x62\x06proto3')
  ,
  dependencies=[CasperMessage__pb2.DESCRIPTOR,google_dot_protobuf_dot_empty__pb2.DESCRIPTOR,scalapb_dot_scalapb__pb2.DESCRIPTOR,RhoTypes__pb2.DESCRIPTOR,])




_FINDDEPLOYQUERY = _descriptor.Descriptor(
  name='FindDeployQuery',
  full_name='casper.FindDeployQuery',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='deployId', full_name='casper.FindDeployQuery.deployId', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=126,
  serialized_end=161,
)


_BLOCKQUERY = _descriptor.Descriptor(
  name='BlockQuery',
  full_name='casper.BlockQuery',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='hash', full_name='casper.BlockQuery.hash', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=163,
  serialized_end=189,
)


_BLOCKSQUERY = _descriptor.Descriptor(
  name='BlocksQuery',
  full_name='casper.BlocksQuery',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='depth', full_name='casper.BlocksQuery.depth', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=191,
  serialized_end=219,
)


_DATAATNAMEQUERY = _descriptor.Descriptor(
  name='DataAtNameQuery',
  full_name='casper.DataAtNameQuery',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='depth', full_name='casper.DataAtNameQuery.depth', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='name', full_name='casper.DataAtNameQuery.name', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=221,
  serialized_end=273,
)


_CONTINUATIONATNAMEQUERY = _descriptor.Descriptor(
  name='ContinuationAtNameQuery',
  full_name='casper.ContinuationAtNameQuery',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='depth', full_name='casper.ContinuationAtNameQuery.depth', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='names', full_name='casper.ContinuationAtNameQuery.names', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=275,
  serialized_end=336,
)


_VISUALIZEDAGQUERY = _descriptor.Descriptor(
  name='VisualizeDagQuery',
  full_name='casper.VisualizeDagQuery',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='depth', full_name='casper.VisualizeDagQuery.depth', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='showJustificationLines', full_name='casper.VisualizeDagQuery.showJustificationLines', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=338,
  serialized_end=404,
)


_MACHINEVERIFYQUERY = _descriptor.Descriptor(
  name='MachineVerifyQuery',
  full_name='casper.MachineVerifyQuery',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=406,
  serialized_end=426,
)


_PRIVATENAMEPREVIEWQUERY = _descriptor.Descriptor(
  name='PrivateNamePreviewQuery',
  full_name='casper.PrivateNamePreviewQuery',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='user', full_name='casper.PrivateNamePreviewQuery.user', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='timestamp', full_name='casper.PrivateNamePreviewQuery.timestamp', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='nameQty', full_name='casper.PrivateNamePreviewQuery.nameQty', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=428,
  serialized_end=503,
)


_LASTFINALIZEDBLOCKQUERY = _descriptor.Descriptor(
  name='LastFinalizedBlockQuery',
  full_name='casper.LastFinalizedBlockQuery',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=505,
  serialized_end=530,
)


_ISFINALIZEDQUERY = _descriptor.Descriptor(
  name='IsFinalizedQuery',
  full_name='casper.IsFinalizedQuery',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='hash', full_name='casper.IsFinalizedQuery.hash', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=532,
  serialized_end=564,
)


_BONDSTATUSQUERY = _descriptor.Descriptor(
  name='BondStatusQuery',
  full_name='casper.BondStatusQuery',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='publicKey', full_name='casper.BondStatusQuery.publicKey', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=566,
  serialized_end=602,
)


_BONDINFO = _descriptor.Descriptor(
  name='BondInfo',
  full_name='casper.BondInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='validator', full_name='casper.BondInfo.validator', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='stake', full_name='casper.BondInfo.stake', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=604,
  serialized_end=648,
)


_DEPLOYINFO = _descriptor.Descriptor(
  name='DeployInfo',
  full_name='casper.DeployInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='deployer', full_name='casper.DeployInfo.deployer', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='term', full_name='casper.DeployInfo.term', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='timestamp', full_name='casper.DeployInfo.timestamp', index=2,
      number=3, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sig', full_name='casper.DeployInfo.sig', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sigAlgorithm', full_name='casper.DeployInfo.sigAlgorithm', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='phloPrice', full_name='casper.DeployInfo.phloPrice', index=5,
      number=7, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='phloLimit', full_name='casper.DeployInfo.phloLimit', index=6,
      number=8, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='validAfterBlockNumber', full_name='casper.DeployInfo.validAfterBlockNumber', index=7,
      number=9, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='cost', full_name='casper.DeployInfo.cost', index=8,
      number=10, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='errored', full_name='casper.DeployInfo.errored', index=9,
      number=11, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='systemDeployError', full_name='casper.DeployInfo.systemDeployError', index=10,
      number=12, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=651,
  serialized_end=876,
)


_LIGHTBLOCKINFO = _descriptor.Descriptor(
  name='LightBlockInfo',
  full_name='casper.LightBlockInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='blockHash', full_name='casper.LightBlockInfo.blockHash', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sender', full_name='casper.LightBlockInfo.sender', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='seqNum', full_name='casper.LightBlockInfo.seqNum', index=2,
      number=3, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sig', full_name='casper.LightBlockInfo.sig', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sigAlgorithm', full_name='casper.LightBlockInfo.sigAlgorithm', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='shardId', full_name='casper.LightBlockInfo.shardId', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='extraBytes', full_name='casper.LightBlockInfo.extraBytes', index=6,
      number=7, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='version', full_name='casper.LightBlockInfo.version', index=7,
      number=8, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='timestamp', full_name='casper.LightBlockInfo.timestamp', index=8,
      number=9, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='headerExtraBytes', full_name='casper.LightBlockInfo.headerExtraBytes', index=9,
      number=10, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='parentsHashList', full_name='casper.LightBlockInfo.parentsHashList', index=10,
      number=11, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='blockNumber', full_name='casper.LightBlockInfo.blockNumber', index=11,
      number=12, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='preStateHash', full_name='casper.LightBlockInfo.preStateHash', index=12,
      number=13, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='postStateHash', full_name='casper.LightBlockInfo.postStateHash', index=13,
      number=14, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='bodyExtraBytes', full_name='casper.LightBlockInfo.bodyExtraBytes', index=14,
      number=15, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='bonds', full_name='casper.LightBlockInfo.bonds', index=15,
      number=16, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='blockSize', full_name='casper.LightBlockInfo.blockSize', index=16,
      number=17, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='deployCount', full_name='casper.LightBlockInfo.deployCount', index=17,
      number=18, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='faultTolerance', full_name='casper.LightBlockInfo.faultTolerance', index=18,
      number=19, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=879,
  serialized_end=1292,
)


_BLOCKINFO = _descriptor.Descriptor(
  name='BlockInfo',
  full_name='casper.BlockInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='blockInfo', full_name='casper.BlockInfo.blockInfo', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='deploys', full_name='casper.BlockInfo.deploys', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1294,
  serialized_end=1385,
)


_DATAWITHBLOCKINFO = _descriptor.Descriptor(
  name='DataWithBlockInfo',
  full_name='casper.DataWithBlockInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='postBlockData', full_name='casper.DataWithBlockInfo.postBlockData', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='block', full_name='casper.DataWithBlockInfo.block', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1387,
  serialized_end=1474,
)


_CONTINUATIONSWITHBLOCKINFO = _descriptor.Descriptor(
  name='ContinuationsWithBlockInfo',
  full_name='casper.ContinuationsWithBlockInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='postBlockContinuations', full_name='casper.ContinuationsWithBlockInfo.postBlockContinuations', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='block', full_name='casper.ContinuationsWithBlockInfo.block', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1477,
  serialized_end=1609,
)


_WAITINGCONTINUATIONINFO = _descriptor.Descriptor(
  name='WaitingContinuationInfo',
  full_name='casper.WaitingContinuationInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='postBlockPatterns', full_name='casper.WaitingContinuationInfo.postBlockPatterns', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='postBlockContinuation', full_name='casper.WaitingContinuationInfo.postBlockContinuation', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1611,
  serialized_end=1714,
)

_DATAATNAMEQUERY.fields_by_name['name'].message_type = RhoTypes__pb2._PAR
_CONTINUATIONATNAMEQUERY.fields_by_name['names'].message_type = RhoTypes__pb2._PAR
_LIGHTBLOCKINFO.fields_by_name['bonds'].message_type = _BONDINFO
_BLOCKINFO.fields_by_name['blockInfo'].message_type = _LIGHTBLOCKINFO
_BLOCKINFO.fields_by_name['deploys'].message_type = _DEPLOYINFO
_DATAWITHBLOCKINFO.fields_by_name['postBlockData'].message_type = RhoTypes__pb2._PAR
_DATAWITHBLOCKINFO.fields_by_name['block'].message_type = _LIGHTBLOCKINFO
_CONTINUATIONSWITHBLOCKINFO.fields_by_name['postBlockContinuations'].message_type = _WAITINGCONTINUATIONINFO
_CONTINUATIONSWITHBLOCKINFO.fields_by_name['block'].message_type = _LIGHTBLOCKINFO
_WAITINGCONTINUATIONINFO.fields_by_name['postBlockPatterns'].message_type = RhoTypes__pb2._BINDPATTERN
_WAITINGCONTINUATIONINFO.fields_by_name['postBlockContinuation'].message_type = RhoTypes__pb2._PAR
DESCRIPTOR.message_types_by_name['FindDeployQuery'] = _FINDDEPLOYQUERY
DESCRIPTOR.message_types_by_name['BlockQuery'] = _BLOCKQUERY
DESCRIPTOR.message_types_by_name['BlocksQuery'] = _BLOCKSQUERY
DESCRIPTOR.message_types_by_name['DataAtNameQuery'] = _DATAATNAMEQUERY
DESCRIPTOR.message_types_by_name['ContinuationAtNameQuery'] = _CONTINUATIONATNAMEQUERY
DESCRIPTOR.message_types_by_name['VisualizeDagQuery'] = _VISUALIZEDAGQUERY
DESCRIPTOR.message_types_by_name['MachineVerifyQuery'] = _MACHINEVERIFYQUERY
DESCRIPTOR.message_types_by_name['PrivateNamePreviewQuery'] = _PRIVATENAMEPREVIEWQUERY
DESCRIPTOR.message_types_by_name['LastFinalizedBlockQuery'] = _LASTFINALIZEDBLOCKQUERY
DESCRIPTOR.message_types_by_name['IsFinalizedQuery'] = _ISFINALIZEDQUERY
DESCRIPTOR.message_types_by_name['BondStatusQuery'] = _BONDSTATUSQUERY
DESCRIPTOR.message_types_by_name['BondInfo'] = _BONDINFO
DESCRIPTOR.message_types_by_name['DeployInfo'] = _DEPLOYINFO
DESCRIPTOR.message_types_by_name['LightBlockInfo'] = _LIGHTBLOCKINFO
DESCRIPTOR.message_types_by_name['BlockInfo'] = _BLOCKINFO
DESCRIPTOR.message_types_by_name['DataWithBlockInfo'] = _DATAWITHBLOCKINFO
DESCRIPTOR.message_types_by_name['ContinuationsWithBlockInfo'] = _CONTINUATIONSWITHBLOCKINFO
DESCRIPTOR.message_types_by_name['WaitingContinuationInfo'] = _WAITINGCONTINUATIONINFO
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

FindDeployQuery = _reflection.GeneratedProtocolMessageType('FindDeployQuery', (_message.Message,), {
  'DESCRIPTOR' : _FINDDEPLOYQUERY,
  '__module__' : 'DeployServiceCommon_pb2'
  # @@protoc_insertion_point(class_scope:casper.FindDeployQuery)
  })
_sym_db.RegisterMessage(FindDeployQuery)

BlockQuery = _reflection.GeneratedProtocolMessageType('BlockQuery', (_message.Message,), {
  'DESCRIPTOR' : _BLOCKQUERY,
  '__module__' : 'DeployServiceCommon_pb2'
  # @@protoc_insertion_point(class_scope:casper.BlockQuery)
  })
_sym_db.RegisterMessage(BlockQuery)

BlocksQuery = _reflection.GeneratedProtocolMessageType('BlocksQuery', (_message.Message,), {
  'DESCRIPTOR' : _BLOCKSQUERY,
  '__module__' : 'DeployServiceCommon_pb2'
  # @@protoc_insertion_point(class_scope:casper.BlocksQuery)
  })
_sym_db.RegisterMessage(BlocksQuery)

DataAtNameQuery = _reflection.GeneratedProtocolMessageType('DataAtNameQuery', (_message.Message,), {
  'DESCRIPTOR' : _DATAATNAMEQUERY,
  '__module__' : 'DeployServiceCommon_pb2'
  # @@protoc_insertion_point(class_scope:casper.DataAtNameQuery)
  })
_sym_db.RegisterMessage(DataAtNameQuery)

ContinuationAtNameQuery = _reflection.GeneratedProtocolMessageType('ContinuationAtNameQuery', (_message.Message,), {
  'DESCRIPTOR' : _CONTINUATIONATNAMEQUERY,
  '__module__' : 'DeployServiceCommon_pb2'
  # @@protoc_insertion_point(class_scope:casper.ContinuationAtNameQuery)
  })
_sym_db.RegisterMessage(ContinuationAtNameQuery)

VisualizeDagQuery = _reflection.GeneratedProtocolMessageType('VisualizeDagQuery', (_message.Message,), {
  'DESCRIPTOR' : _VISUALIZEDAGQUERY,
  '__module__' : 'DeployServiceCommon_pb2'
  # @@protoc_insertion_point(class_scope:casper.VisualizeDagQuery)
  })
_sym_db.RegisterMessage(VisualizeDagQuery)

MachineVerifyQuery = _reflection.GeneratedProtocolMessageType('MachineVerifyQuery', (_message.Message,), {
  'DESCRIPTOR' : _MACHINEVERIFYQUERY,
  '__module__' : 'DeployServiceCommon_pb2'
  # @@protoc_insertion_point(class_scope:casper.MachineVerifyQuery)
  })
_sym_db.RegisterMessage(MachineVerifyQuery)

PrivateNamePreviewQuery = _reflection.GeneratedProtocolMessageType('PrivateNamePreviewQuery', (_message.Message,), {
  'DESCRIPTOR' : _PRIVATENAMEPREVIEWQUERY,
  '__module__' : 'DeployServiceCommon_pb2'
  # @@protoc_insertion_point(class_scope:casper.PrivateNamePreviewQuery)
  })
_sym_db.RegisterMessage(PrivateNamePreviewQuery)

LastFinalizedBlockQuery = _reflection.GeneratedProtocolMessageType('LastFinalizedBlockQuery', (_message.Message,), {
  'DESCRIPTOR' : _LASTFINALIZEDBLOCKQUERY,
  '__module__' : 'DeployServiceCommon_pb2'
  # @@protoc_insertion_point(class_scope:casper.LastFinalizedBlockQuery)
  })
_sym_db.RegisterMessage(LastFinalizedBlockQuery)

IsFinalizedQuery = _reflection.GeneratedProtocolMessageType('IsFinalizedQuery', (_message.Message,), {
  'DESCRIPTOR' : _ISFINALIZEDQUERY,
  '__module__' : 'DeployServiceCommon_pb2'
  # @@protoc_insertion_point(class_scope:casper.IsFinalizedQuery)
  })
_sym_db.RegisterMessage(IsFinalizedQuery)

BondStatusQuery = _reflection.GeneratedProtocolMessageType('BondStatusQuery', (_message.Message,), {
  'DESCRIPTOR' : _BONDSTATUSQUERY,
  '__module__' : 'DeployServiceCommon_pb2'
  # @@protoc_insertion_point(class_scope:casper.BondStatusQuery)
  })
_sym_db.RegisterMessage(BondStatusQuery)

BondInfo = _reflection.GeneratedProtocolMessageType('BondInfo', (_message.Message,), {
  'DESCRIPTOR' : _BONDINFO,
  '__module__' : 'DeployServiceCommon_pb2'
  # @@protoc_insertion_point(class_scope:casper.BondInfo)
  })
_sym_db.RegisterMessage(BondInfo)

DeployInfo = _reflection.GeneratedProtocolMessageType('DeployInfo', (_message.Message,), {
  'DESCRIPTOR' : _DEPLOYINFO,
  '__module__' : 'DeployServiceCommon_pb2'
  # @@protoc_insertion_point(class_scope:casper.DeployInfo)
  })
_sym_db.RegisterMessage(DeployInfo)

LightBlockInfo = _reflection.GeneratedProtocolMessageType('LightBlockInfo', (_message.Message,), {
  'DESCRIPTOR' : _LIGHTBLOCKINFO,
  '__module__' : 'DeployServiceCommon_pb2'
  # @@protoc_insertion_point(class_scope:casper.LightBlockInfo)
  })
_sym_db.RegisterMessage(LightBlockInfo)

BlockInfo = _reflection.GeneratedProtocolMessageType('BlockInfo', (_message.Message,), {
  'DESCRIPTOR' : _BLOCKINFO,
  '__module__' : 'DeployServiceCommon_pb2'
  # @@protoc_insertion_point(class_scope:casper.BlockInfo)
  })
_sym_db.RegisterMessage(BlockInfo)

DataWithBlockInfo = _reflection.GeneratedProtocolMessageType('DataWithBlockInfo', (_message.Message,), {
  'DESCRIPTOR' : _DATAWITHBLOCKINFO,
  '__module__' : 'DeployServiceCommon_pb2'
  # @@protoc_insertion_point(class_scope:casper.DataWithBlockInfo)
  })
_sym_db.RegisterMessage(DataWithBlockInfo)

ContinuationsWithBlockInfo = _reflection.GeneratedProtocolMessageType('ContinuationsWithBlockInfo', (_message.Message,), {
  'DESCRIPTOR' : _CONTINUATIONSWITHBLOCKINFO,
  '__module__' : 'DeployServiceCommon_pb2'
  # @@protoc_insertion_point(class_scope:casper.ContinuationsWithBlockInfo)
  })
_sym_db.RegisterMessage(ContinuationsWithBlockInfo)

WaitingContinuationInfo = _reflection.GeneratedProtocolMessageType('WaitingContinuationInfo', (_message.Message,), {
  'DESCRIPTOR' : _WAITINGCONTINUATIONINFO,
  '__module__' : 'DeployServiceCommon_pb2'
  # @@protoc_insertion_point(class_scope:casper.WaitingContinuationInfo)
  })
_sym_db.RegisterMessage(WaitingContinuationInfo)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



from pathlib import Path

import setuptools

setuptools.setup(
    name='pyrchain',
    version='0.2.0',
    author='RChain Cooperative',
    author_email='rchain-makers@rchain.coop',
    description='Interface to RChain RNode RPC',
    long_description=Path('README.md').read_text(),
    long_description_content_type='text/markdown',
    url='https://github.com/rchain/pyrchain',
    packages=setuptools.find_namespace_packages(include=['rchain', 'rchain.*']),
    package_data={'rchain.vault': ['*.rho.tpl']},
    install_requires=[
        'grpcio',
        'protobuf',
        'ecdsa',
        'python-bitcoinlib',
        'cryptography',
        'eth_hash',
        'pycryptodome'
    ],
    extras_require={'dev': ['grpcio-tools', 'mypy', 'typing-extensions', 'mypy-protobuf', 'isort', 'pytest', 'typeshed']}
)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: DeployServiceV1.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import CasperMessage_pb2 as CasperMessage__pb2
from . import ServiceError_pb2 as ServiceError__pb2
from . import DeployServiceCommon_pb2 as DeployServiceCommon__pb2
from .scalapb import scalapb_pb2 as scalapb_dot_scalapb__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='DeployServiceV1.proto',
  package='casper.v1',
  syntax='proto3',
  serialized_options=_b('\342?+\n%coop.rchain.casper.protocol.deploy.v1\020\001(\001'),
  serialized_pb=_b('\n\x15\x44\x65ployServiceV1.proto\x12\tcasper.v1\x1a\x13\x43\x61sperMessage.proto\x1a\x12ServiceError.proto\x1a\x19\x44\x65ployServiceCommon.proto\x1a\x15scalapb/scalapb.proto\"M\n\x0e\x44\x65ployResponse\x12\x1e\n\x05\x65rror\x18\x01 \x01(\x0b\x32\r.ServiceErrorH\x00\x12\x10\n\x06result\x18\x02 \x01(\tH\x00\x42\t\n\x07message\"b\n\rBlockResponse\x12\x1e\n\x05\x65rror\x18\x01 \x01(\x0b\x32\r.ServiceErrorH\x00\x12&\n\tblockInfo\x18\x02 \x01(\x0b\x32\x11.casper.BlockInfoH\x00\x42\t\n\x07message\"W\n\x17VisualizeBlocksResponse\x12\x1e\n\x05\x65rror\x18\x01 \x01(\x0b\x32\r.ServiceErrorH\x00\x12\x11\n\x07\x63ontent\x18\x02 \x01(\tH\x00\x42\t\n\x07message\"U\n\x15MachineVerifyResponse\x12\x1e\n\x05\x65rror\x18\x01 \x01(\x0b\x32\r.ServiceErrorH\x00\x12\x11\n\x07\x63ontent\x18\x02 \x01(\tH\x00\x42\t\n\x07message\"k\n\x11\x42lockInfoResponse\x12\x1e\n\x05\x65rror\x18\x01 \x01(\x0b\x32\r.ServiceErrorH\x00\x12+\n\tblockInfo\x18\x02 \x01(\x0b\x32\x16.casper.LightBlockInfoH\x00\x42\t\n\x07message\"~\n\x19ListeningNameDataResponse\x12\x1e\n\x05\x65rror\x18\x01 \x01(\x0b\x32\r.ServiceErrorH\x00\x12\x36\n\x07payload\x18\x02 \x01(\x0b\x32#.casper.v1.ListeningNameDataPayloadH\x00\x42\t\n\x07message\"X\n\x18ListeningNameDataPayload\x12,\n\tblockInfo\x18\x01 \x03(\x0b\x32\x19.casper.DataWithBlockInfo\x12\x0e\n\x06length\x18\x02 \x01(\x05\"\x80\x01\n\x1a\x43ontinuationAtNameResponse\x12\x1e\n\x05\x65rror\x18\x01 \x01(\x0b\x32\r.ServiceErrorH\x00\x12\x37\n\x07payload\x18\x02 \x01(\x0b\x32$.casper.v1.ContinuationAtNamePayloadH\x00\x42\t\n\x07message\"e\n\x19\x43ontinuationAtNamePayload\x12\x38\n\x0c\x62lockResults\x18\x01 \x03(\x0b\x32\".casper.ContinuationsWithBlockInfo\x12\x0e\n\x06length\x18\x02 \x01(\x05\"l\n\x12\x46indDeployResponse\x12\x1e\n\x05\x65rror\x18\x01 \x01(\x0b\x32\r.ServiceErrorH\x00\x12+\n\tblockInfo\x18\x02 \x01(\x0b\x32\x16.casper.LightBlockInfoH\x00\x42\t\n\x07message\"\x80\x01\n\x1aPrivateNamePreviewResponse\x12\x1e\n\x05\x65rror\x18\x01 \x01(\x0b\x32\r.ServiceErrorH\x00\x12\x37\n\x07payload\x18\x02 \x01(\x0b\x32$.casper.v1.PrivateNamePreviewPayloadH\x00\x42\t\n\x07message\"(\n\x19PrivateNamePreviewPayload\x12\x0b\n\x03ids\x18\x01 \x03(\x0c\"o\n\x1aLastFinalizedBlockResponse\x12\x1e\n\x05\x65rror\x18\x01 \x01(\x0b\x32\r.ServiceErrorH\x00\x12&\n\tblockInfo\x18\x02 \x01(\x0b\x32\x11.casper.BlockInfoH\x00\x42\t\n\x07message\"W\n\x13IsFinalizedResponse\x12\x1e\n\x05\x65rror\x18\x01 \x01(\x0b\x32\r.ServiceErrorH\x00\x12\x15\n\x0bisFinalized\x18\x02 \x01(\x08H\x00\x42\t\n\x07message\"S\n\x12\x42ondStatusResponse\x12\x1e\n\x05\x65rror\x18\x01 \x01(\x0b\x32\r.ServiceErrorH\x00\x12\x12\n\x08isBonded\x18\x02 \x01(\x08H\x00\x42\t\n\x07message2\xa1\x08\n\rDeployService\x12@\n\x08\x64oDeploy\x12\x17.casper.DeployDataProto\x1a\x19.casper.v1.DeployResponse\"\x00\x12:\n\x08getBlock\x12\x12.casper.BlockQuery\x1a\x18.casper.v1.BlockResponse\"\x00\x12Q\n\x0cvisualizeDag\x12\x19.casper.VisualizeDagQuery\x1a\".casper.v1.VisualizeBlocksResponse\"\x00\x30\x01\x12V\n\x14machineVerifiableDag\x12\x1a.casper.MachineVerifyQuery\x1a .casper.v1.MachineVerifyResponse\"\x00\x12\x46\n\rshowMainChain\x12\x13.casper.BlocksQuery\x1a\x1c.casper.v1.BlockInfoResponse\"\x00\x30\x01\x12\x42\n\tgetBlocks\x12\x13.casper.BlocksQuery\x1a\x1c.casper.v1.BlockInfoResponse\"\x00\x30\x01\x12V\n\x13listenForDataAtName\x12\x17.casper.DataAtNameQuery\x1a$.casper.v1.ListeningNameDataResponse\"\x00\x12g\n\x1blistenForContinuationAtName\x12\x1f.casper.ContinuationAtNameQuery\x1a%.casper.v1.ContinuationAtNameResponse\"\x00\x12\x46\n\nfindDeploy\x12\x17.casper.FindDeployQuery\x1a\x1d.casper.v1.FindDeployResponse\"\x00\x12_\n\x13previewPrivateNames\x12\x1f.casper.PrivateNamePreviewQuery\x1a%.casper.v1.PrivateNamePreviewResponse\"\x00\x12^\n\x12lastFinalizedBlock\x12\x1f.casper.LastFinalizedBlockQuery\x1a%.casper.v1.LastFinalizedBlockResponse\"\x00\x12I\n\x0bisFinalized\x12\x18.casper.IsFinalizedQuery\x1a\x1e.casper.v1.IsFinalizedResponse\"\x00\x12\x46\n\nbondStatus\x12\x17.casper.BondStatusQuery\x1a\x1d.casper.v1.BondStatusResponse\"\x00\x42.\xe2?+\n%coop.rchain.casper.protocol.deploy.v1\x10\x01(\x01\x62\x06proto3')
  ,
  dependencies=[CasperMessage__pb2.DESCRIPTOR,ServiceError__pb2.DESCRIPTOR,DeployServiceCommon__pb2.DESCRIPTOR,scalapb_dot_scalapb__pb2.DESCRIPTOR,])




_DEPLOYRESPONSE = _descriptor.Descriptor(
  name='DeployResponse',
  full_name='casper.v1.DeployResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='error', full_name='casper.v1.DeployResponse.error', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='result', full_name='casper.v1.DeployResponse.result', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='message', full_name='casper.v1.DeployResponse.message',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=127,
  serialized_end=204,
)


_BLOCKRESPONSE = _descriptor.Descriptor(
  name='BlockResponse',
  full_name='casper.v1.BlockResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='error', full_name='casper.v1.BlockResponse.error', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='blockInfo', full_name='casper.v1.BlockResponse.blockInfo', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='message', full_name='casper.v1.BlockResponse.message',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=206,
  serialized_end=304,
)


_VISUALIZEBLOCKSRESPONSE = _descriptor.Descriptor(
  name='VisualizeBlocksResponse',
  full_name='casper.v1.VisualizeBlocksResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='error', full_name='casper.v1.VisualizeBlocksResponse.error', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='content', full_name='casper.v1.VisualizeBlocksResponse.content', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='message', full_name='casper.v1.VisualizeBlocksResponse.message',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=306,
  serialized_end=393,
)


_MACHINEVERIFYRESPONSE = _descriptor.Descriptor(
  name='MachineVerifyResponse',
  full_name='casper.v1.MachineVerifyResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='error', full_name='casper.v1.MachineVerifyResponse.error', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='content', full_name='casper.v1.MachineVerifyResponse.content', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='message', full_name='casper.v1.MachineVerifyResponse.message',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=395,
  serialized_end=480,
)


_BLOCKINFORESPONSE = _descriptor.Descriptor(
  name='BlockInfoResponse',
  full_name='casper.v1.BlockInfoResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='error', full_name='casper.v1.BlockInfoResponse.error', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='blockInfo', full_name='casper.v1.BlockInfoResponse.blockInfo', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='message', full_name='casper.v1.BlockInfoResponse.message',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=482,
  serialized_end=589,
)


_LISTENINGNAMEDATARESPONSE = _descriptor.Descriptor(
  name='ListeningNameDataResponse',
  full_name='casper.v1.ListeningNameDataResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='error', full_name='casper.v1.ListeningNameDataResponse.error', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='payload', full_name='casper.v1.ListeningNameDataResponse.payload', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='message', full_name='casper.v1.ListeningNameDataResponse.message',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=591,
  serialized_end=717,
)


_LISTENINGNAMEDATAPAYLOAD = _descriptor.Descriptor(
  name='ListeningNameDataPayload',
  full_name='casper.v1.ListeningNameDataPayload',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='blockInfo', full_name='casper.v1.ListeningNameDataPayload.blockInfo', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='length', full_name='casper.v1.ListeningNameDataPayload.length', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=719,
  serialized_end=807,
)


_CONTINUATIONATNAMERESPONSE = _descriptor.Descriptor(
  name='ContinuationAtNameResponse',
  full_name='casper.v1.ContinuationAtNameResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='error', full_name='casper.v1.ContinuationAtNameResponse.error', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='payload', full_name='casper.v1.ContinuationAtNameResponse.payload', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='message', full_name='casper.v1.ContinuationAtNameResponse.message',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=810,
  serialized_end=938,
)


_CONTINUATIONATNAMEPAYLOAD = _descriptor.Descriptor(
  name='ContinuationAtNamePayload',
  full_name='casper.v1.ContinuationAtNamePayload',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='blockResults', full_name='casper.v1.ContinuationAtNamePayload.blockResults', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='length', full_name='casper.v1.ContinuationAtNamePayload.length', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=940,
  serialized_end=1041,
)


_FINDDEPLOYRESPONSE = _descriptor.Descriptor(
  name='FindDeployResponse',
  full_name='casper.v1.FindDeployResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='error', full_name='casper.v1.FindDeployResponse.error', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='blockInfo', full_name='casper.v1.FindDeployResponse.blockInfo', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='message', full_name='casper.v1.FindDeployResponse.message',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=1043,
  serialized_end=1151,
)


_PRIVATENAMEPREVIEWRESPONSE = _descriptor.Descriptor(
  name='PrivateNamePreviewResponse',
  full_name='casper.v1.PrivateNamePreviewResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='error', full_name='casper.v1.PrivateNamePreviewResponse.error', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='payload', full_name='casper.v1.PrivateNamePreviewResponse.payload', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='message', full_name='casper.v1.PrivateNamePreviewResponse.message',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=1154,
  serialized_end=1282,
)


_PRIVATENAMEPREVIEWPAYLOAD = _descriptor.Descriptor(
  name='PrivateNamePreviewPayload',
  full_name='casper.v1.PrivateNamePreviewPayload',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='ids', full_name='casper.v1.PrivateNamePreviewPayload.ids', index=0,
      number=1, type=12, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1284,
  serialized_end=1324,
)


_LASTFINALIZEDBLOCKRESPONSE = _descriptor.Descriptor(
  name='LastFinalizedBlockResponse',
  full_name='casper.v1.LastFinalizedBlockResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='error', full_name='casper.v1.LastFinalizedBlockResponse.error', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='blockInfo', full_name='casper.v1.LastFinalizedBlockResponse.blockInfo', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='message', full_name='casper.v1.LastFinalizedBlockResponse.message',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=1326,
  serialized_end=1437,
)


_ISFINALIZEDRESPONSE = _descriptor.Descriptor(
  name='IsFinalizedResponse',
  full_name='casper.v1.IsFinalizedResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='error', full_name='casper.v1.IsFinalizedResponse.error', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='isFinalized', full_name='casper.v1.IsFinalizedResponse.isFinalized', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='message', full_name='casper.v1.IsFinalizedResponse.message',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=1439,
  serialized_end=1526,
)


_BONDSTATUSRESPONSE = _descriptor.Descriptor(
  name='BondStatusResponse',
  full_name='casper.v1.BondStatusResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='error', full_name='casper.v1.BondStatusResponse.error', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='isBonded', full_name='casper.v1.BondStatusResponse.isBonded', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='message', full_name='casper.v1.BondStatusResponse.message',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=1528,
  serialized_end=1611,
)

_DEPLOYRESPONSE.fields_by_name['error'].message_type = ServiceError__pb2._SERVICEERROR
_DEPLOYRESPONSE.oneofs_by_name['message'].fields.append(
  _DEPLOYRESPONSE.fields_by_name['error'])
_DEPLOYRESPONSE.fields_by_name['error'].containing_oneof = _DEPLOYRESPONSE.oneofs_by_name['message']
_DEPLOYRESPONSE.oneofs_by_name['message'].fields.append(
  _DEPLOYRESPONSE.fields_by_name['result'])
_DEPLOYRESPONSE.fields_by_name['result'].containing_oneof = _DEPLOYRESPONSE.oneofs_by_name['message']
_BLOCKRESPONSE.fields_by_name['error'].message_type = ServiceError__pb2._SERVICEERROR
_BLOCKRESPONSE.fields_by_name['blockInfo'].message_type = DeployServiceCommon__pb2._BLOCKINFO
_BLOCKRESPONSE.oneofs_by_name['message'].fields.append(
  _BLOCKRESPONSE.fields_by_name['error'])
_BLOCKRESPONSE.fields_by_name['error'].containing_oneof = _BLOCKRESPONSE.oneofs_by_name['message']
_BLOCKRESPONSE.oneofs_by_name['message'].fields.append(
  _BLOCKRESPONSE.fields_by_name['blockInfo'])
_BLOCKRESPONSE.fields_by_name['blockInfo'].containing_oneof = _BLOCKRESPONSE.oneofs_by_name['message']
_VISUALIZEBLOCKSRESPONSE.fields_by_name['error'].message_type = ServiceError__pb2._SERVICEERROR
_VISUALIZEBLOCKSRESPONSE.oneofs_by_name['message'].fields.append(
  _VISUALIZEBLOCKSRESPONSE.fields_by_name['error'])
_VISUALIZEBLOCKSRESPONSE.fields_by_name['error'].containing_oneof = _VISUALIZEBLOCKSRESPONSE.oneofs_by_name['message']
_VISUALIZEBLOCKSRESPONSE.oneofs_by_name['message'].fields.append(
  _VISUALIZEBLOCKSRESPONSE.fields_by_name['content'])
_VISUALIZEBLOCKSRESPONSE.fields_by_name['content'].containing_oneof = _VISUALIZEBLOCKSRESPONSE.oneofs_by_name['message']
_MACHINEVERIFYRESPONSE.fields_by_name['error'].message_type = ServiceError__pb2._SERVICEERROR
_MACHINEVERIFYRESPONSE.oneofs_by_name['message'].fields.append(
  _MACHINEVERIFYRESPONSE.fields_by_name['error'])
_MACHINEVERIFYRESPONSE.fields_by_name['error'].containing_oneof = _MACHINEVERIFYRESPONSE.oneofs_by_name['message']
_MACHINEVERIFYRESPONSE.oneofs_by_name['message'].fields.append(
  _MACHINEVERIFYRESPONSE.fields_by_name['content'])
_MACHINEVERIFYRESPONSE.fields_by_name['content'].containing_oneof = _MACHINEVERIFYRESPONSE.oneofs_by_name['message']
_BLOCKINFORESPONSE.fields_by_name['error'].message_type = ServiceError__pb2._SERVICEERROR
_BLOCKINFORESPONSE.fields_by_name['blockInfo'].message_type = DeployServiceCommon__pb2._LIGHTBLOCKINFO
_BLOCKINFORESPONSE.oneofs_by_name['message'].fields.append(
  _BLOCKINFORESPONSE.fields_by_name['error'])
_BLOCKINFORESPONSE.fields_by_name['error'].containing_oneof = _BLOCKINFORESPONSE.oneofs_by_name['message']
_BLOCKINFORESPONSE.oneofs_by_name['message'].fields.append(
  _BLOCKINFORESPONSE.fields_by_name['blockInfo'])
_BLOCKINFORESPONSE.fields_by_name['blockInfo'].containing_oneof = _BLOCKINFORESPONSE.oneofs_by_name['message']
_LISTENINGNAMEDATARESPONSE.fields_by_name['error'].message_type = ServiceError__pb2._SERVICEERROR
_LISTENINGNAMEDATARESPONSE.fields_by_name['payload'].message_type = _LISTENINGNAMEDATAPAYLOAD
_LISTENINGNAMEDATARESPONSE.oneofs_by_name['message'].fields.append(
  _LISTENINGNAMEDATARESPONSE.fields_by_name['error'])
_LISTENINGNAMEDATARESPONSE.fields_by_name['error'].containing_oneof = _LISTENINGNAMEDATARESPONSE.oneofs_by_name['message']
_LISTENINGNAMEDATARESPONSE.oneofs_by_name['message'].fields.append(
  _LISTENINGNAMEDATARESPONSE.fields_by_name['payload'])
_LISTENINGNAMEDATARESPONSE.fields_by_name['payload'].containing_oneof = _LISTENINGNAMEDATARESPONSE.oneofs_by_name['message']
_LISTENINGNAMEDATAPAYLOAD.fields_by_name['blockInfo'].message_type = DeployServiceCommon__pb2._DATAWITHBLOCKINFO
_CONTINUATIONATNAMERESPONSE.fields_by_name['error'].message_type = ServiceError__pb2._SERVICEERROR
_CONTINUATIONATNAMERESPONSE.fields_by_name['payload'].message_type = _CONTINUATIONATNAMEPAYLOAD
_CONTINUATIONATNAMERESPONSE.oneofs_by_name['message'].fields.append(
  _CONTINUATIONATNAMERESPONSE.fields_by_name['error'])
_CONTINUATIONATNAMERESPONSE.fields_by_name['error'].containing_oneof = _CONTINUATIONATNAMERESPONSE.oneofs_by_name['message']
_CONTINUATIONATNAMERESPONSE.oneofs_by_name['message'].fields.append(
  _CONTINUATIONATNAMERESPONSE.fields_by_name['payload'])
_CONTINUATIONATNAMERESPONSE.fields_by_name['payload'].containing_oneof = _CONTINUATIONATNAMERESPONSE.oneofs_by_name['message']
_CONTINUATIONATNAMEPAYLOAD.fields_by_name['blockResults'].message_type = DeployServiceCommon__pb2._CONTINUATIONSWITHBLOCKINFO
_FINDDEPLOYRESPONSE.fields_by_name['error'].message_type = ServiceError__pb2._SERVICEERROR
_FINDDEPLOYRESPONSE.fields_by_name['blockInfo'].message_type = DeployServiceCommon__pb2._LIGHTBLOCKINFO
_FINDDEPLOYRESPONSE.oneofs_by_name['message'].fields.append(
  _FINDDEPLOYRESPONSE.fields_by_name['error'])
_FINDDEPLOYRESPONSE.fields_by_name['error'].containing_oneof = _FINDDEPLOYRESPONSE.oneofs_by_name['message']
_FINDDEPLOYRESPONSE.oneofs_by_name['message'].fields.append(
  _FINDDEPLOYRESPONSE.fields_by_name['blockInfo'])
_FINDDEPLOYRESPONSE.fields_by_name['blockInfo'].containing_oneof = _FINDDEPLOYRESPONSE.oneofs_by_name['message']
_PRIVATENAMEPREVIEWRESPONSE.fields_by_name['error'].message_type = ServiceError__pb2._SERVICEERROR
_PRIVATENAMEPREVIEWRESPONSE.fields_by_name['payload'].message_type = _PRIVATENAMEPREVIEWPAYLOAD
_PRIVATENAMEPREVIEWRESPONSE.oneofs_by_name['message'].fields.append(
  _PRIVATENAMEPREVIEWRESPONSE.fields_by_name['error'])
_PRIVATENAMEPREVIEWRESPONSE.fields_by_name['error'].containing_oneof = _PRIVATENAMEPREVIEWRESPONSE.oneofs_by_name['message']
_PRIVATENAMEPREVIEWRESPONSE.oneofs_by_name['message'].fields.append(
  _PRIVATENAMEPREVIEWRESPONSE.fields_by_name['payload'])
_PRIVATENAMEPREVIEWRESPONSE.fields_by_name['payload'].containing_oneof = _PRIVATENAMEPREVIEWRESPONSE.oneofs_by_name['message']
_LASTFINALIZEDBLOCKRESPONSE.fields_by_name['error'].message_type = ServiceError__pb2._SERVICEERROR
_LASTFINALIZEDBLOCKRESPONSE.fields_by_name['blockInfo'].message_type = DeployServiceCommon__pb2._BLOCKINFO
_LASTFINALIZEDBLOCKRESPONSE.oneofs_by_name['message'].fields.append(
  _LASTFINALIZEDBLOCKRESPONSE.fields_by_name['error'])
_LASTFINALIZEDBLOCKRESPONSE.fields_by_name['error'].containing_oneof = _LASTFINALIZEDBLOCKRESPONSE.oneofs_by_name['message']
_LASTFINALIZEDBLOCKRESPONSE.oneofs_by_name['message'].fields.append(
  _LASTFINALIZEDBLOCKRESPONSE.fields_by_name['blockInfo'])
_LASTFINALIZEDBLOCKRESPONSE.fields_by_name['blockInfo'].containing_oneof = _LASTFINALIZEDBLOCKRESPONSE.oneofs_by_name['message']
_ISFINALIZEDRESPONSE.fields_by_name['error'].message_type = ServiceError__pb2._SERVICEERROR
_ISFINALIZEDRESPONSE.oneofs_by_name['message'].fields.append(
  _ISFINALIZEDRESPONSE.fields_by_name['error'])
_ISFINALIZEDRESPONSE.fields_by_name['error'].containing_oneof = _ISFINALIZEDRESPONSE.oneofs_by_name['message']
_ISFINALIZEDRESPONSE.oneofs_by_name['message'].fields.append(
  _ISFINALIZEDRESPONSE.fields_by_name['isFinalized'])
_ISFINALIZEDRESPONSE.fields_by_name['isFinalized'].containing_oneof = _ISFINALIZEDRESPONSE.oneofs_by_name['message']
_BONDSTATUSRESPONSE.fields_by_name['error'].message_type = ServiceError__pb2._SERVICEERROR
_BONDSTATUSRESPONSE.oneofs_by_name['message'].fields.append(
  _BONDSTATUSRESPONSE.fields_by_name['error'])
_BONDSTATUSRESPONSE.fields_by_name['error'].containing_oneof = _BONDSTATUSRESPONSE.oneofs_by_name['message']
_BONDSTATUSRESPONSE.oneofs_by_name['message'].fields.append(
  _BONDSTATUSRESPONSE.fields_by_name['isBonded'])
_BONDSTATUSRESPONSE.fields_by_name['isBonded'].containing_oneof = _BONDSTATUSRESPONSE.oneofs_by_name['message']
DESCRIPTOR.message_types_by_name['DeployResponse'] = _DEPLOYRESPONSE
DESCRIPTOR.message_types_by_name['BlockResponse'] = _BLOCKRESPONSE
DESCRIPTOR.message_types_by_name['VisualizeBlocksResponse'] = _VISUALIZEBLOCKSRESPONSE
DESCRIPTOR.message_types_by_name['MachineVerifyResponse'] = _MACHINEVERIFYRESPONSE
DESCRIPTOR.message_types_by_name['BlockInfoResponse'] = _BLOCKINFORESPONSE
DESCRIPTOR.message_types_by_name['ListeningNameDataResponse'] = _LISTENINGNAMEDATARESPONSE
DESCRIPTOR.message_types_by_name['ListeningNameDataPayload'] = _LISTENINGNAMEDATAPAYLOAD
DESCRIPTOR.message_types_by_name['ContinuationAtNameResponse'] = _CONTINUATIONATNAMERESPONSE
DESCRIPTOR.message_types_by_name['ContinuationAtNamePayload'] = _CONTINUATIONATNAMEPAYLOAD
DESCRIPTOR.message_types_by_name['FindDeployResponse'] = _FINDDEPLOYRESPONSE
DESCRIPTOR.message_types_by_name['PrivateNamePreviewResponse'] = _PRIVATENAMEPREVIEWRESPONSE
DESCRIPTOR.message_types_by_name['PrivateNamePreviewPayload'] = _PRIVATENAMEPREVIEWPAYLOAD
DESCRIPTOR.message_types_by_name['LastFinalizedBlockResponse'] = _LASTFINALIZEDBLOCKRESPONSE
DESCRIPTOR.message_types_by_name['IsFinalizedResponse'] = _ISFINALIZEDRESPONSE
DESCRIPTOR.message_types_by_name['BondStatusResponse'] = _BONDSTATUSRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

DeployResponse = _reflection.GeneratedProtocolMessageType('DeployResponse', (_message.Message,), {
  'DESCRIPTOR' : _DEPLOYRESPONSE,
  '__module__' : 'DeployServiceV1_pb2'
  # @@protoc_insertion_point(class_scope:casper.v1.DeployResponse)
  })
_sym_db.RegisterMessage(DeployResponse)

BlockResponse = _reflection.GeneratedProtocolMessageType('BlockResponse', (_message.Message,), {
  'DESCRIPTOR' : _BLOCKRESPONSE,
  '__module__' : 'DeployServiceV1_pb2'
  # @@protoc_insertion_point(class_scope:casper.v1.BlockResponse)
  })
_sym_db.RegisterMessage(BlockResponse)

VisualizeBlocksResponse = _reflection.GeneratedProtocolMessageType('VisualizeBlocksResponse', (_message.Message,), {
  'DESCRIPTOR' : _VISUALIZEBLOCKSRESPONSE,
  '__module__' : 'DeployServiceV1_pb2'
  # @@protoc_insertion_point(class_scope:casper.v1.VisualizeBlocksResponse)
  })
_sym_db.RegisterMessage(VisualizeBlocksResponse)

MachineVerifyResponse = _reflection.GeneratedProtocolMessageType('MachineVerifyResponse', (_message.Message,), {
  'DESCRIPTOR' : _MACHINEVERIFYRESPONSE,
  '__module__' : 'DeployServiceV1_pb2'
  # @@protoc_insertion_point(class_scope:casper.v1.MachineVerifyResponse)
  })
_sym_db.RegisterMessage(MachineVerifyResponse)

BlockInfoResponse = _reflection.GeneratedProtocolMessageType('BlockInfoResponse', (_message.Message,), {
  'DESCRIPTOR' : _BLOCKINFORESPONSE,
  '__module__' : 'DeployServiceV1_pb2'
  # @@protoc_insertion_point(class_scope:casper.v1.BlockInfoResponse)
  })
_sym_db.RegisterMessage(BlockInfoResponse)

ListeningNameDataResponse = _reflection.GeneratedProtocolMessageType('ListeningNameDataResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTENINGNAMEDATARESPONSE,
  '__module__' : 'DeployServiceV1_pb2'
  # @@protoc_insertion_point(class_scope:casper.v1.ListeningNameDataResponse)
  })
_sym_db.RegisterMessage(ListeningNameDataResponse)

ListeningNameDataPayload = _reflection.GeneratedProtocolMessageType('ListeningNameDataPayload', (_message.Message,), {
  'DESCRIPTOR' : _LISTENINGNAMEDATAPAYLOAD,
  '__module__' : 'DeployServiceV1_pb2'
  # @@protoc_insertion_point(class_scope:casper.v1.ListeningNameDataPayload)
  })
_sym_db.RegisterMessage(ListeningNameDataPayload)

ContinuationAtNameResponse = _reflection.GeneratedProtocolMessageType('ContinuationAtNameResponse', (_message.Message,), {
  'DESCRIPTOR' : _CONTINUATIONATNAMERESPONSE,
  '__module__' : 'DeployServiceV1_pb2'
  # @@protoc_insertion_point(class_scope:casper.v1.ContinuationAtNameResponse)
  })
_sym_db.RegisterMessage(ContinuationAtNameResponse)

ContinuationAtNamePayload = _reflection.GeneratedProtocolMessageType('ContinuationAtNamePayload', (_message.Message,), {
  'DESCRIPTOR' : _CONTINUATIONATNAMEPAYLOAD,
  '__module__' : 'DeployServiceV1_pb2'
  # @@protoc_insertion_point(class_scope:casper.v1.ContinuationAtNamePayload)
  })
_sym_db.RegisterMessage(ContinuationAtNamePayload)

FindDeployResponse = _reflection.GeneratedProtocolMessageType('FindDeployResponse', (_message.Message,), {
  'DESCRIPTOR' : _FINDDEPLOYRESPONSE,
  '__module__' : 'DeployServiceV1_pb2'
  # @@protoc_insertion_point(class_scope:casper.v1.FindDeployResponse)
  })
_sym_db.RegisterMessage(FindDeployResponse)

PrivateNamePreviewResponse = _reflection.GeneratedProtocolMessageType('PrivateNamePreviewResponse', (_message.Message,), {
  'DESCRIPTOR' : _PRIVATENAMEPREVIEWRESPONSE,
  '__module__' : 'DeployServiceV1_pb2'
  # @@protoc_insertion_point(class_scope:casper.v1.PrivateNamePreviewResponse)
  })
_sym_db.RegisterMessage(PrivateNamePreviewResponse)

PrivateNamePreviewPayload = _reflection.GeneratedProtocolMessageType('PrivateNamePreviewPayload', (_message.Message,), {
  'DESCRIPTOR' : _PRIVATENAMEPREVIEWPAYLOAD,
  '__module__' : 'DeployServiceV1_pb2'
  # @@protoc_insertion_point(class_scope:casper.v1.PrivateNamePreviewPayload)
  })
_sym_db.RegisterMessage(PrivateNamePreviewPayload)

LastFinalizedBlockResponse = _reflection.GeneratedProtocolMessageType('LastFinalizedBlockResponse', (_message.Message,), {
  'DESCRIPTOR' : _LASTFINALIZEDBLOCKRESPONSE,
  '__module__' : 'DeployServiceV1_pb2'
  # @@protoc_insertion_point(class_scope:casper.v1.LastFinalizedBlockResponse)
  })
_sym_db.RegisterMessage(LastFinalizedBlockResponse)

IsFinalizedResponse = _reflection.GeneratedProtocolMessageType('IsFinalizedResponse', (_message.Message,), {
  'DESCRIPTOR' : _ISFINALIZEDRESPONSE,
  '__module__' : 'DeployServiceV1_pb2'
  # @@protoc_insertion_point(class_scope:casper.v1.IsFinalizedResponse)
  })
_sym_db.RegisterMessage(IsFinalizedResponse)

BondStatusResponse = _reflection.GeneratedProtocolMessageType('BondStatusResponse', (_message.Message,), {
  'DESCRIPTOR' : _BONDSTATUSRESPONSE,
  '__module__' : 'DeployServiceV1_pb2'
  # @@protoc_insertion_point(class_scope:casper.v1.BondStatusResponse)
  })
_sym_db.RegisterMessage(BondStatusResponse)


DESCRIPTOR._options = None

_DEPLOYSERVICE = _descriptor.ServiceDescriptor(
  name='DeployService',
  full_name='casper.v1.DeployService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  serialized_start=1614,
  serialized_end=2671,
  methods=[
  _descriptor.MethodDescriptor(
    name='doDeploy',
    full_name='casper.v1.DeployService.doDeploy',
    index=0,
    containing_service=None,
    input_type=CasperMessage__pb2._DEPLOYDATAPROTO,
    output_type=_DEPLOYRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='getBlock',
    full_name='casper.v1.DeployService.getBlock',
    index=1,
    containing_service=None,
    input_type=DeployServiceCommon__pb2._BLOCKQUERY,
    output_type=_BLOCKRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='visualizeDag',
    full_name='casper.v1.DeployService.visualizeDag',
    index=2,
    containing_service=None,
    input_type=DeployServiceCommon__pb2._VISUALIZEDAGQUERY,
    output_type=_VISUALIZEBLOCKSRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='machineVerifiableDag',
    full_name='casper.v1.DeployService.machineVerifiableDag',
    index=3,
    containing_service=None,
    input_type=DeployServiceCommon__pb2._MACHINEVERIFYQUERY,
    output_type=_MACHINEVERIFYRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='showMainChain',
    full_name='casper.v1.DeployService.showMainChain',
    index=4,
    containing_service=None,
    input_type=DeployServiceCommon__pb2._BLOCKSQUERY,
    output_type=_BLOCKINFORESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='getBlocks',
    full_name='casper.v1.DeployService.getBlocks',
    index=5,
    containing_service=None,
    input_type=DeployServiceCommon__pb2._BLOCKSQUERY,
    output_type=_BLOCKINFORESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='listenForDataAtName',
    full_name='casper.v1.DeployService.listenForDataAtName',
    index=6,
    containing_service=None,
    input_type=DeployServiceCommon__pb2._DATAATNAMEQUERY,
    output_type=_LISTENINGNAMEDATARESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='listenForContinuationAtName',
    full_name='casper.v1.DeployService.listenForContinuationAtName',
    index=7,
    containing_service=None,
    input_type=DeployServiceCommon__pb2._CONTINUATIONATNAMEQUERY,
    output_type=_CONTINUATIONATNAMERESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='findDeploy',
    full_name='casper.v1.DeployService.findDeploy',
    index=8,
    containing_service=None,
    input_type=DeployServiceCommon__pb2._FINDDEPLOYQUERY,
    output_type=_FINDDEPLOYRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='previewPrivateNames',
    full_name='casper.v1.DeployService.previewPrivateNames',
    index=9,
    containing_service=None,
    input_type=DeployServiceCommon__pb2._PRIVATENAMEPREVIEWQUERY,
    output_type=_PRIVATENAMEPREVIEWRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='lastFinalizedBlock',
    full_name='casper.v1.DeployService.lastFinalizedBlock',
    index=10,
    containing_service=None,
    input_type=DeployServiceCommon__pb2._LASTFINALIZEDBLOCKQUERY,
    output_type=_LASTFINALIZEDBLOCKRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='isFinalized',
    full_name='casper.v1.DeployService.isFinalized',
    index=11,
    containing_service=None,
    input_type=DeployServiceCommon__pb2._ISFINALIZEDQUERY,
    output_type=_ISFINALIZEDRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='bondStatus',
    full_name='casper.v1.DeployService.bondStatus',
    index=12,
    containing_service=None,
    input_type=DeployServiceCommon__pb2._BONDSTATUSQUERY,
    output_type=_BONDSTATUSRESPONSE,
    serialized_options=None,
  ),
])
_sym_db.RegisterServiceDescriptor(_DEPLOYSERVICE)

DESCRIPTOR.services_by_name['DeployService'] = _DEPLOYSERVICE

# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ProposeServiceCommon.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from .scalapb import scalapb_pb2 as scalapb_dot_scalapb__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='ProposeServiceCommon.proto',
  package='casper',
  syntax='proto3',
  serialized_options=_b('\342?!\n\033coop.rchain.casper.protocol\020\001(\001'),
  serialized_pb=_b('\n\x1aProposeServiceCommon.proto\x12\x06\x63\x61sper\x1a\x15scalapb/scalapb.proto\"7\n\x18PrintUnmatchedSendsQuery\x12\x1b\n\x13printUnmatchedSends\x18\x01 \x01(\x08\x42$\xe2?!\n\x1b\x63oop.rchain.casper.protocol\x10\x01(\x01\x62\x06proto3')
  ,
  dependencies=[scalapb_dot_scalapb__pb2.DESCRIPTOR,])




_PRINTUNMATCHEDSENDSQUERY = _descriptor.Descriptor(
  name='PrintUnmatchedSendsQuery',
  full_name='casper.PrintUnmatchedSendsQuery',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='printUnmatchedSends', full_name='casper.PrintUnmatchedSendsQuery.printUnmatchedSends', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=61,
  serialized_end=116,
)

DESCRIPTOR.message_types_by_name['PrintUnmatchedSendsQuery'] = _PRINTUNMATCHEDSENDSQUERY
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

PrintUnmatchedSendsQuery = _reflection.GeneratedProtocolMessageType('PrintUnmatchedSendsQuery', (_message.Message,), {
  'DESCRIPTOR' : _PRINTUNMATCHEDSENDSQUERY,
  '__module__' : 'ProposeServiceCommon_pb2'
  # @@protoc_insertion_point(class_scope:casper.PrintUnmatchedSendsQuery)
  })
_sym_db.RegisterMessage(PrintUnmatchedSendsQuery)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)
